<?php
/*************************************************************************
 *    @file AprivaPaymentReq.php                                          
 *    @brief This class builds up a Credit Card Sale request to be        
 *           submitted thru the Apriva XML Interface.  Bare minimum       
 *           fields have be defined.  Please contact Apriva for           
 *           encoding of additional fields.                              
 *    @author P Heit                                                      
 *    @date Sept 21, 2013                                                 
 *                                                                        
 *    Copyright (c) 2013 by                                               
 *       Apriva LLC                                                       
 *    All rights reserved.                                                
 *                                                                        
 *    This software is furnished under a license and may be used and      
 *    copied only in accordance with the terms of such license and with   
 *    the inclusion of the above copyright notice. This software or       
 *    any other copies thereof may not be provided or otherwise made      
 *    available to any other person or entity. Neither title to nor       
 *    ownership of the software is hereby transferred.                    
 *************************************************************************/
     class AprivaPaymentReq {
     	
     	private $xmlObj;
     		
       	// Build up default XML Request 
       	function __construct() {
            $this->xmlObj = new SimpleXMLElement("<AprivaPosXml><Credit MessageType=\"Request\" Version=\"5.0\" ProcessingCode=\"Sale\"></Credit></AprivaPosXml>");
   		}    	
  
        // Define what account should be used to process the transaction
 		function SetMerchantNumber($mnum)
  		{
  			$this->xmlObj->addAttribute('DeviceAddress', $mnum);
 		}
  				
        // Get the merchant account that was set within the request.
  		function GetMerchantNumber()
  		{
  			$array =  $this->xmlObj->attributes();
  			return $array["DeviceAddress"];
 		}

        // Set the information required to process a manual transaction.
  		function SetManualCardData($ccnum, $expDate, $cardPresent)
  		{
 			$this->xmlObj->Credit->addChild('AccountNumber');
 			$this->xmlObj->Credit->AccountNumber = $ccnum;
 
 			$this->xmlObj->Credit->addChild('ExpireDate');
 			$this->xmlObj->Credit->ExpireDate = $expDate;
  
			$this->xmlObj->Credit->addChild('EntryMode');
 			$this->xmlObj->Credit->EntryMode = "Manual";

 			$this->xmlObj->Credit->addChild('EntryModeType');
 			$this->xmlObj->Credit->EntryModeType = "Standard";
 
  			$this->xmlObj->Credit->addChild('CardPresent');
 			
 			if ($cardPresent)
 				$this->xmlObj->Credit->CardPresent = "YES";
 			else
	 			$this->xmlObj->Credit->CardPresent = "NO";
 		}

        // Set the information required to process a swiped transaction.
  		function SetTrackData($track2)
  		{
 			$this->xmlObj->Credit->addChild('Track2');
 			$this->xmlObj->Credit->Track2 = $track2;

 			$this->xmlObj->Credit->addChild('EntryMode');
 			$this->xmlObj->Credit->EntryMode = "Track2";

 			$this->xmlObj->Credit->addChild('EntryModeType');
 			$this->xmlObj->Credit->EntryModeType = "Standard";
 			
 			$this->xmlObj->Credit->addChild('CardPresent');
 			$this->xmlObj->Credit->CardPresent = "YES";
  		}
   
        // Set the amount of the transaction.
  		function SetAmount($amount)
  		{
 			$this->xmlObj->Credit->addChild('Amount');
 			$this->xmlObj->Credit->Amount = $amount;
  		}
 
        // Set the card verification value
  		function SetCVV($cvv)
  		{
 			$this->xmlObj->Credit->addChild('CardVerification');
 			$this->xmlObj->Credit->CardVerification->addChild('Indicator');
 			$this->xmlObj->Credit->CardVerification->Indicator = "ValuePresent";
 			$this->xmlObj->Credit->CardVerification->addChild('Value');
 			$this->xmlObj->Credit->CardVerification->Value = $cvv;
 			
  		}
 
        // Set the billing postal code
   		function SetPostalCode($postalcode)
  		{
 			$this->xmlObj->Credit->addChild('AddressVerify');
 			$this->xmlObj->Credit->AddressVerify->addChild('ZipCode');
 			$this->xmlObj->Credit->AddressVerify->ZipCode = $postalcode;
  		}
  		
        // Set the system trace number (aka. STAN)
   		function SetSystemTraceNumber($stan)
  		{
 			$this->xmlObj->Credit->addChild('Stan');
 			$this->xmlObj->Credit->Stan = $stan;
  		}
  		
        // Get the system trace number (aka. STAN)
   		function GetSystemTraceNumber()
  		{
 			return $this->xmlObj->Credit->Stan;
  		}

        // Set the system trace number (aka. STAN)
        // Parameters : field number (1 to 5) and the data
   		function SetReportField($num, $data)
  		{
   			if ($num == 1)
   			{
 	  			if ( !isset($this->xmlObj->Credit->ReportingData) )
  					$this->xmlObj->Credit->addChild("ReportingData");
 				$this->xmlObj->Credit->ReportingData->addChild('RDetail1');
 				$this->xmlObj->Credit->ReportingData->RDetail1 = $data;
 			}
   			else if ($num == 2)
   			{
   				if ( !isset($this->xmlObj->Credit->ReportingData) )
  					$this->xmlObj->Credit->addChild("ReportingData");
 				$this->xmlObj->Credit->ReportingData->addChild('RDetail2');
 				$this->xmlObj->Credit->ReportingData->RDetail2 = $data;
  			}
   			else if ($num == 3)
   			{
 	   			if ( !isset($this->xmlObj->Credit->ReportingData) )
  					$this->xmlObj->Credit->addChild("ReportingData");
 				$this->xmlObj->Credit->ReportingData->addChild('RDetail3');
 				$this->xmlObj->Credit->ReportingData->RDetail3 = $data;
  			}
   			else if ($num == 4)
   			{
	   			if ( !isset($this->xmlObj->Credit->ReportingData) )
  					$this->xmlObj->Credit->addChild("ReportingData");
 				$this->xmlObj->Credit->ReportingData->addChild('RDetail4');
 				$this->xmlObj->Credit->ReportingData->RDetail4 = $data;
  			}
   			else if ($num == 5)
   			{
 	  			if ( !isset($this->xmlObj->Credit->ReportingData) )
  					$this->xmlObj->Credit->addChild("ReportingData");
 				$this->xmlObj->Credit->ReportingData->addChild('RDetail5');
 				$this->xmlObj->Credit->ReportingData->RDetail5 = $data;
 			}
  		}
  		
  		// Get the encoded data.
  		function asXML()
  		{
  			return $this->xmlObj->asXML();
  		}
    }
    
   ?>
